diff --git a/Code/Mantid/API/inc/MantidAPI/FrameworkManager.h b/Code/Mantid/API/inc/MantidAPI/FrameworkManager.h
index d06b82e5b0674ed357ee7c7600826795594a18c5..25b084ecfc09ac7ddfbf8a3e036a4c238bab867b 100644
--- a/Code/Mantid/API/inc/MantidAPI/FrameworkManager.h
+++ b/Code/Mantid/API/inc/MantidAPI/FrameworkManager.h
@@ -10,14 +10,6 @@
 #include "MantidKernel/Logger.h"
 #include "MantidKernel/LibraryManager.h"
 
-namespace Mantid
-{
-namespace Kernel
-{
-class ConfigService;
-}
-}
-
 namespace Mantid
 {
 namespace API
@@ -106,8 +98,6 @@ private:
  
   /// Pointer to the Workspace Factory instance
   WorkspaceFactory *workFactory;
-  /// Pointer to the Configuration Service
-  Kernel::ConfigService *config;
   
 };
 
diff --git a/Code/Mantid/API/src/FrameworkManager.cpp b/Code/Mantid/API/src/FrameworkManager.cpp
index 3d1e67fb991e049a3486d6774dc0ca81faa137ad..b085672342ee74eaf298cddb310eff690b5d4ce5 100644
--- a/Code/Mantid/API/src/FrameworkManager.cpp
+++ b/Code/Mantid/API/src/FrameworkManager.cpp
@@ -43,14 +43,10 @@ FrameworkManager::~FrameworkManager()
 
 /// Creates all of the required services
 void FrameworkManager::initialize()
-{
-  // Required services are: the config service, the algorithm manager
-  //     the analysis data service, the workspace factory
-	
-  config = Kernel::ConfigService::Instance();
+{ 
   workFactory = WorkspaceFactory::Instance();
 
-  std::string pluginDir = config->getString("plugins.directory");
+  std::string pluginDir = Kernel::ConfigService::Instance().getString("plugins.directory");
   if (pluginDir.length() > 0)
   {
     Mantid::Kernel::LibraryManager::Instance().OpenAllLibraries(pluginDir, false);
diff --git a/Code/Mantid/API/src/WorkspaceFactory.cpp b/Code/Mantid/API/src/WorkspaceFactory.cpp
index e007c6105f8165eb6533aa9a72091c08fe700dda..3c48d65eb5c825f986faebb81388d2146eba236d 100644
--- a/Code/Mantid/API/src/WorkspaceFactory.cpp
+++ b/Code/Mantid/API/src/WorkspaceFactory.cpp
@@ -64,7 +64,7 @@ Workspace_sptr WorkspaceFactory::create(const std::string& className, const int&
   
   // Now decide what kind of 2D workspace to create according to the size
   int triggerSize;
-  if ( ! Kernel::ConfigService::Instance()->getValue("ManagedWorkspace.MinSize", triggerSize) )
+  if ( ! Kernel::ConfigService::Instance().getValue("ManagedWorkspace.MinSize", triggerSize) )
   {
     // Default to 20M elements if missing
     triggerSize = 25000000;
diff --git a/Code/Mantid/DataObjects/src/ManagedWorkspace2D.cpp b/Code/Mantid/DataObjects/src/ManagedWorkspace2D.cpp
index 528768508f5acc7a7f2c2bcfb0b73a2f71083a54..e79a81b0ac437909b075562f1b5e62806b2f4a45 100644
--- a/Code/Mantid/DataObjects/src/ManagedWorkspace2D.cpp
+++ b/Code/Mantid/DataObjects/src/ManagedWorkspace2D.cpp
@@ -40,9 +40,8 @@ void ManagedWorkspace2D::init(const int &NVectors, const int &XLength, const int
   m_XLength = XLength;
   m_YLength = YLength;
   
-  Kernel::ConfigService* configSvc = Kernel::ConfigService::Instance();
   // Look for the (optional) path from the configuration file
-  std::string path = configSvc->getString("ManagedWorkspace.FilePath");
+  std::string path = Kernel::ConfigService::Instance().getString("ManagedWorkspace.FilePath");
   if ( !path.empty() )
   {
     if ( ( *(path.rbegin()) != '/' ) && ( *(path.rbegin()) != '\\' ) )
@@ -85,7 +84,7 @@ void ManagedWorkspace2D::init(const int &NVectors, const int &XLength, const int
   // CALCULATE BLOCKSIZE
   // Get memory size of a block from config file
   int blockMemory;
-  if ( ! configSvc->getValue("ManagedWorkspace.DataBlockSize", blockMemory) 
+  if ( ! Kernel::ConfigService::Instance().getValue("ManagedWorkspace.DataBlockSize", blockMemory) 
       || blockMemory <= 0 )
   {
     // default to 1MB if property not found
diff --git a/Code/Mantid/Kernel/inc/MantidKernel/ConfigService.h b/Code/Mantid/Kernel/inc/MantidKernel/ConfigService.h
index 01f4c42da2eef9fe753f6442f4aeb732e8942468..63c22843501c39f6c9190a20593351910c0c108c 100644
--- a/Code/Mantid/Kernel/inc/MantidKernel/ConfigService.h
+++ b/Code/Mantid/Kernel/inc/MantidKernel/ConfigService.h
@@ -9,6 +9,14 @@
 #include <iostream>
 #include <iomanip>
 #include <string>
+#include "MantidKernel/SingletonHolder.h"
+
+#ifdef IN_MANTID_KERNEL
+#define EXPORT_OPT_MANTID_KERNEL DLLExport 
+#else
+#define EXPORT_OPT_MANTID_KERNEL DLLImport
+#endif /* IN_MANTID_API */
+
 
 //----------------------------------------------------------------------
 // Forward declaration
@@ -58,7 +66,7 @@ namespace Kernel
     File change history is stored at: <https://svn.mantidproject.org/mantid/trunk/Code/Mantid>.
     Code Documentation is available at: <http://doxygen.mantidproject.org>
 */
-	class DLLExport ConfigService
+	class EXPORT_OPT_MANTID_KERNEL ConfigServiceImpl
 	{
 	  /** Inner templated class to wrap the poco library objects that have protected 
 	   *  desctructors and expose them as public.
@@ -111,9 +119,6 @@ namespace Kernel
 	  // Back to the ConfigService class itself...
 	  
 	public:	
-	  // Returns the single instance of the service
-		static ConfigService* Instance();
-
 		// Loads a config file
 		void loadConfig(const std::string& filename);
 		
@@ -137,25 +142,28 @@ namespace Kernel
 		std::string getTempDir();
 
 	private:
+		friend struct Mantid::Kernel::CreateUsingNew<ConfigServiceImpl>;
+	
 	  // Private constructors and destructor for singleton class
-		ConfigService();
+		ConfigServiceImpl();
 		/// Private copy constructor. Prevents singleton being copied.
-		ConfigService(const ConfigService&) {}
+		ConfigServiceImpl(const ConfigServiceImpl&) {}
 	    
-    virtual ~ConfigService();
+		virtual ~ConfigServiceImpl();
 
     /// the POCO file config object
 		WrappedObject<Poco::Util::PropertyFileConfiguration>* m_pConf;
 		/// the POCO system Config Object
 		WrappedObject<Poco::Util::SystemConfiguration>* m_pSysConfig;
 
-		/// Pointer to the factory instance
-		static ConfigService* m_instance;
-
     /// static reference to the logger class
 	  static Logger& g_log;
 
 	};
+	
+	///Forward declaration of a specialisation of SingletonHolder for AlgorithmFactoryImpl (needed for dllexport/dllimport) and a typedef for it.
+	template class EXPORT_OPT_MANTID_KERNEL Mantid::Kernel::SingletonHolder<ConfigServiceImpl>;
+	typedef EXPORT_OPT_MANTID_KERNEL Mantid::Kernel::SingletonHolder<ConfigServiceImpl> ConfigService;
 
 } // namespace Kernel
 } // namespace Mantid
diff --git a/Code/Mantid/Kernel/test/ConfigServiceTest.h b/Code/Mantid/Kernel/test/ConfigServiceTest.h
index 31556bf230cf21736d8f10666c23f1d8443e317b..7eb695064bcd9227eaf76f492b290dbf466b653a 100644
--- a/Code/Mantid/Kernel/test/ConfigServiceTest.h
+++ b/Code/Mantid/Kernel/test/ConfigServiceTest.h
@@ -15,8 +15,7 @@ public:
 
   ConfigServiceTest()
   {
-	  configSvc = ConfigService::Instance();
-	  configSvc->loadConfig("MantidTest.properties");
+	  ConfigService::Instance().loadConfig("MantidTest.properties");
   }
 
   void testLogging()
@@ -52,22 +51,22 @@ public:
   {
 	  //we cannot test the return values here as they will differ based on the environment.
 	  //therfore we will just check they return a non empty string.
-	  std::string osName = configSvc->getOSName();
+	  std::string osName = ConfigService::Instance().getOSName();
 	  TS_ASSERT_LESS_THAN(0, osName.length()); //check that the string is not empty
-	  std::string osArch = configSvc->getOSArchitecture();
+	  std::string osArch = ConfigService::Instance().getOSArchitecture();
 	  TS_ASSERT_LESS_THAN(0, osArch.length()); //check that the string is not empty
-	  std::string osCompName = configSvc->getComputerName();
+	  std::string osCompName = ConfigService::Instance().getComputerName();
 	  TS_ASSERT_LESS_THAN(0, osCompName.length()); //check that the string is not empty
-	  TS_ASSERT_LESS_THAN(0, configSvc->getOSVersion().length()); //check that the string is not empty
-	  TS_ASSERT_LESS_THAN(0, configSvc->getCurrentDir().length()); //check that the string is not empty
-	  TS_ASSERT_LESS_THAN(0, configSvc->getHomeDir().length()); //check that the string is not empty
-	  TS_ASSERT_LESS_THAN(0, configSvc->getTempDir().length()); //check that the string is not empty
+	  TS_ASSERT_LESS_THAN(0, ConfigService::Instance().getOSVersion().length()); //check that the string is not empty
+	  TS_ASSERT_LESS_THAN(0, ConfigService::Instance().getCurrentDir().length()); //check that the string is not empty
+	  TS_ASSERT_LESS_THAN(0, ConfigService::Instance().getHomeDir().length()); //check that the string is not empty
+	  TS_ASSERT_LESS_THAN(0, ConfigService::Instance().getTempDir().length()); //check that the string is not empty
   }
 
   void TestCustomProperty()
   {
 	  //Mantid.legs is defined in the properties script as 6
-	  std::string legCountString = configSvc->getString("mantid.legs");
+	  std::string legCountString = ConfigService::Instance().getString("mantid.legs");
 	  TS_ASSERT_EQUALS(legCountString, "6");
   }
 
@@ -75,9 +74,9 @@ public:
   {
 	  //Mantid.legs is defined in the properties script as 6
 	  int value;
-	  int retVal = configSvc->getValue("mantid.legs",value);
+	  int retVal = ConfigService::Instance().getValue("mantid.legs",value);
 	  double dblValue;
-	  retVal = configSvc->getValue("mantid.legs",dblValue);
+	  retVal = ConfigService::Instance().getValue("mantid.legs",dblValue);
 
 	  TS_ASSERT_EQUALS(value, 6);
 	  TS_ASSERT_EQUALS(dblValue, 6.0);
@@ -86,7 +85,7 @@ public:
   void TestMissingProperty()
   {
 	  //Mantid.noses is not defined in the properties script 
-	  std::string noseCountString = configSvc->getString("mantid.noses");
+	  std::string noseCountString = ConfigService::Instance().getString("mantid.noses");
     //this should return an empty string
 
 	  TS_ASSERT_EQUALS(noseCountString, "");
diff --git a/Code/Mantid/Kernel/src/ConfigService.cpp b/Code/Mantid/Kernel/src/ConfigService.cpp
index 9188cdae35400051dad00037c75d42fee7aeb32e..6a8d27014f12019c7e35670f5a931fcf1a5544a5 100644
--- a/Code/Mantid/Kernel/src/ConfigService.cpp
+++ b/Code/Mantid/Kernel/src/ConfigService.cpp
@@ -14,39 +14,28 @@ namespace Mantid
 {
 namespace Kernel
 {
-	// Initialise the instance pointer to zero
-	ConfigService* ConfigService::m_instance=0;
-
   // Get a reference to the logger
-  Logger& ConfigService::g_log = Logger::get("ConfigService");
-
-  /** A static method which retrieves the single instance of the ConfigService
-   *
-   * @returns A pointer to the instance
-   */
-	ConfigService* ConfigService::Instance()
-	{
-		if (!m_instance) m_instance = new ConfigService;
-		return m_instance;
-	}
+  Logger& ConfigServiceImpl::g_log = Logger::get("ConfigService");
 
-	/// Private constructor for singleton class
-	ConfigService::ConfigService()
+  /// Private constructor for singleton class
+	ConfigServiceImpl::ConfigServiceImpl()
 	{
 		//getting at system details
 		m_pSysConfig = new WrappedObject<Poco::Util::SystemConfiguration>;
 		m_pConf = 0;
 		//attempt to load the default properties filename
 		loadConfig("Mantid.properties");
+		g_log.debug() << "ConfigService created." << std::endl;
 	}
 
   /** Private Destructor
    *  Prevents client from calling 'delete' on the pointer handed out by Instance
    */
-	ConfigService::~ConfigService()
+	ConfigServiceImpl::~ConfigServiceImpl()
 	{
 		delete m_pSysConfig;
 		delete m_pConf;                // potential double delete???
+		g_log.debug() << "ConfigService destroyed." << std::endl;
 	}
 
 
@@ -55,7 +44,7 @@ namespace Kernel
    *
    *  @param filename The filename and optionally path of the file to load
    */
-	void ConfigService::loadConfig(const std::string& filename)
+	void ConfigServiceImpl::loadConfig(const std::string& filename)
 	{
 		delete m_pConf;
 
@@ -92,7 +81,7 @@ namespace Kernel
 			//configure the logging framework
 			Poco::Util::LoggingConfigurator configurator;
 			
 			//BUG? This line crashes the FrameworkManagerTest and ConfigServiceTest
 			configurator.configure(m_pConf);
 		}
 		catch (std::exception& e)
@@ -107,7 +96,7 @@ namespace Kernel
    *  @param keyName The case sensitive name of the property that you need the value of.
    *  @returns The string value of the property, or an empty string if the key cannot be found
    */
-	std::string ConfigService::getString(const std::string& keyName)
+	std::string ConfigServiceImpl::getString(const std::string& keyName)
 	{
     std::string retVal;
     try
@@ -130,7 +119,7 @@ namespace Kernel
    *  @returns A success flag - 0 on failure, 1 on success
    */
 	template<typename T>
-	int ConfigService::getValue(const std::string& keyName, T& out)
+	int ConfigServiceImpl::getValue(const std::string& keyName, T& out)
 	{
 		std::string strValue = getString(keyName);
 		int result = StrFunc::convert(strValue,out);
@@ -143,7 +132,7 @@ namespace Kernel
    *  @param keyName The name of the environment variable that you need the value of.
    *  @returns The string value of the property
    */
-	std::string ConfigService::getEnvironment(const std::string& keyName)	
+	std::string ConfigServiceImpl::getEnvironment(const std::string& keyName)	
 	{
 		return m_pSysConfig->getString("system.env." + keyName);
 	}
@@ -152,7 +141,7 @@ namespace Kernel
    *
    *  @returns The name pf the OS version
    */
-	std::string ConfigService::getOSName()
+	std::string ConfigServiceImpl::getOSName()
 	{
 		return m_pSysConfig->getString("system.osName");
 	}
@@ -161,7 +150,7 @@ namespace Kernel
    *
    *  @returns The  name of the computer
    */
-	std::string ConfigService::getOSArchitecture()
+	std::string ConfigServiceImpl::getOSArchitecture()
 	{
 		return m_pSysConfig->getString("system.osArchitecture");
 	}
@@ -170,7 +159,7 @@ namespace Kernel
    *
    * @returns The operating system architecture
    */
-	std::string ConfigService::getComputerName()
+	std::string ConfigServiceImpl::getComputerName()
 	{
 		return m_pSysConfig->getString("system.nodeName");
 	}
@@ -179,7 +168,7 @@ namespace Kernel
    *
    * @returns The operating system version
    */
-	std::string ConfigService::getOSVersion()
+	std::string ConfigServiceImpl::getOSVersion()
 	{
 		return m_pSysConfig->getString("system.osVersion");
 	}
@@ -188,7 +177,7 @@ namespace Kernel
    *
    * @returns The absolute path of the current directory containing the dll
    */
-	std::string ConfigService::getCurrentDir()
+	std::string ConfigServiceImpl::getCurrentDir()
 	{
 		return m_pSysConfig->getString("system.currentDir");
 	}
@@ -197,7 +186,7 @@ namespace Kernel
    *
    * @returns The absolute path of the home directory 
    */
-	std::string ConfigService::getHomeDir()
+	std::string ConfigServiceImpl::getHomeDir()
 	{
 		return m_pSysConfig->getString("system.homeDir");
 	}
@@ -206,7 +195,7 @@ namespace Kernel
    *
    * @returns The absolute path of the temp directory 
    */
-	std::string ConfigService::getTempDir()
+	std::string ConfigServiceImpl::getTempDir()
 	{
 		return m_pSysConfig->getString("system.tempDir");
 	}
@@ -215,9 +204,9 @@ namespace Kernel
 	
 /// \cond TEMPLATE 
 
-	template DLLExport int ConfigService::getValue(const std::string&,double&);
-	template DLLExport int ConfigService::getValue(const std::string&,std::string&);
-	template DLLExport int ConfigService::getValue(const std::string&,int&);
+	template DLLExport int ConfigServiceImpl::getValue(const std::string&,double&);
+	template DLLExport int ConfigServiceImpl::getValue(const std::string&,std::string&);
+	template DLLExport int ConfigServiceImpl::getValue(const std::string&,int&);
 
 /// \endcond TEMPLATE
 
@@ -92,7 +81,7 @@ namespace Kernel
 			Poco::Util::LoggingConfigurator configurator;
 			
-			//BUG? This line crashes the FrameworkManagerTest and ConfigServiceTest
+			//BUG? This line crashes the FrameworkManagerTest and ConfigServiceImplTest
 			configurator.configure(m_pConf);
 		}